Units of parameters
============================

GADMA shows model parameters in genetic units. To scale them from one should multiply migration rates by 2 only. Other units are as usual. In case when option ``Relative parameters`` is set to ``True`` one should first rescale from units of ``Nref``: sizes of populations - multiply by ``Nref``, time - multiply by ``2 * Nref`` migration rates - divide by ``2 * Nref``.